- Deprecate module ``xoutil.logger``.

- Remove deprecated function ``xoutil.iterators.fake_dict_iteritems``.

- Add ``xoutil.objects.temp_attributes``.

- Add functions ``xoutil.fp.tools.fst`` and ``xoutil.fp.tools.snd``.
